import { ElementRef } from '@angular/core';
import Map from '@arcgis/core/Map';
import { ConfigService } from '../config/config.service';
import { AppConfig } from '../../models/alert/configs/app-config';
import { ApplicationConfig } from '../../models/alert/configs/application-config';
import { IdentityService } from '../identity/identity.service';
import Expand from '@arcgis/core/widgets/Expand';
import Legend from '@arcgis/core/widgets/Legend';
import { default as EsriMapView, default as MapView } from '@arcgis/core/views/MapView';
import { EventsService } from '../event/events.service';
import Bookmarks from '@arcgis/core/widgets/Bookmarks.js';
import Extent from '@arcgis/core/geometry/Extent';
import Point from '@arcgis/core/geometry/Point';
import * as i0 from "@angular/core";
export declare class ArcgisService {
    private configService;
    private eventsService;
    private identityService;
    config: ApplicationConfig;
    searchWidget: any;
    otherHighlightedFeatures: any[];
    plotHighlightedFeatures: any;
    viewBuildingFeatureMap: boolean;
    mapExpandsWidget: Expand[];
    basemapGalleryExpand: Expand;
    legendExpand: Expand;
    coordinateConversionExpand: Expand;
    sketchExpand: Expand;
    toolbarDivExpand: Expand;
    mapScaleDivExpand: Expand;
    symbolBuilderExpand: Expand;
    bookmarks: Bookmarks;
    layerListExpand: Expand;
    legend: Legend | null;
    _prevExtent: boolean;
    _nextExtent: boolean;
    _currentExtent: any;
    _extentHistory: any;
    _extentHistoryIndx: number;
    _preExtent: any;
    layersConfig: any;
    initialExtent: Extent;
    constructor(configService: ConfigService, eventsService: EventsService, identityService: IdentityService);
    initializeMap: (appConfig: AppConfig, itemid: string, mapViewEl: ElementRef) => Promise<EsriMapView>;
    addWidgetsOnScreen(config: ApplicationConfig, mapView: EsriMapView): void;
    createComponentContainer(hideInMobileView: boolean): HTMLDivElement;
    private removeUnwantedFormats;
    trackingg: (mapView: MapView) => void;
    switchBasemap(mapView: MapView, basemapName: string): void;
    extentChangeHandler: (evt: any) => void;
    increaseZoom(mapView: MapView, increment?: number): void;
    decreaseZoom(mapView: MapView, decrement?: number): void;
    zoomToPrevious: (mapView: MapView) => "Zoomed to Previous Extent" | "No Previous Extent";
    zoomToNext: (mapView: MapView) => "Zoomed to Next Extent" | "No Next Extent";
    addLayerFromURL(mapView: MapView, url: string): Promise<void>;
    layerExists(url: any, map: Map): boolean;
    removeLayerByTitle: (mapView: MapView, layerTitle: string) => void;
    addLayerList(mapView: MapView): void;
    removeLayerList(mapView: MapView): void;
    addLegendList(mapView: MapView): void;
    removeLegendList(mapView: MapView): void;
    applyExportFunction(mapView: MapView): void;
    getLayerByTitle(mapView: MapView, layerTitle: string): any;
    getUrlByLayerName(targetLayerName: string): null | undefined;
    highlightFeatures(mapView: MapView, layerConfigName: string, queryToHighlight: string, type: string): Promise<boolean>;
    zoomToFullExtent(mapView: MapView, title: string): boolean;
    changeLayerOpacity(mapView: MapView, title: string, opacity: number): boolean;
    printService: (mapView: MapView) => Promise<string>;
    generateHrefLink: (url: string, label: string, downloadable: boolean) => string;
    fromBaseToString: (bString: string) => string;
    getMapViewpoint: (mapView: any) => string;
    generateMapViewerUrlFromCurrentLocation: (mapView: MapView) => string;
    shareMap(mapView: MapView): string;
    getPointLongLat: (point: Point) => {
        latitude: string;
        longitude: string;
    } | {
        latitude: null;
        longitude: null;
    };
    addTimeSlider(mapView: MapView, layerId: string): void;
    goToMapFullExtent: (mapView: MapView) => void;
    zoomToLocation: (mapView: MapView, locationName: string) => void;
    getLatLongForPlace(placeName: string): Promise<{
        latitude: number;
        longitude: number;
    } | null>;
    reorderLayer(mapView: MapView, layerTitle: string, index: number): void;
    queryLayer(mapView: MapView, layerTitle: string, queryText: string): void;
    clearHighlightedFeatures: (mapView: MapView) => void;
    getMapViewInfo: (mapView: MapView) => {
        extent: {
            xmin: number;
            ymin: number;
            xmax: number;
            ymax: number;
            spatialReference: {
                wkid: number;
            };
        } | null;
        mapLayersInfo: any[] | null;
    };
    getMapLayersInfo(mapView: MapView): any[] | null;
    setExpandWidgetsToggleListener: () => void;
    initalizeBookmark: (mapView: EsriMapView) => void;
    addBookmark(mapView: EsriMapView, bookmarkName: string): void;
    loadBookmarkByName(mapView: EsriMapView, name: string): void;
    loadBookmarks(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ArcgisService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ArcgisService>;
}
